@@ -25,7 +25,7 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gmodule.h>
-#include <gconf/gconf-client.h>
+#include <gio/gio.h>
 
 #include "gnome-settings-plugin-info.h"
 #include "gnome-settings-module.h"
@@ -48,7 +48,7 @@ typedef enum
 struct GnomeSettingsPluginInfoPrivate
 {
         char                    *file;
-        GConfClient             *client;
+        GSettings               *settings;
 
         char                    *location;
         GnomeSettingsPluginLoader  loader;
@@ -70,8 +70,6 @@ struct GnomeSettingsPluginInfoPrivate
            when the interpreter has not been correctly initializated) */
         int                      available : 1;
 
-        guint                    enabled_notification_id;
-
         /* Priority determines the order in which plugins are started and
          * stopped. A lower number means higher priority. */
         guint                    priority;
@@ -117,15 +115,10 @@ gnome_settings_plugin_info_finalize (GObject *object)
         g_free (info->priv->copyright);
         g_strfreev (info->priv->authors);
 
-        if (info->priv->enabled_notification_id != 0) {
-                gconf_client_notify_remove (info->priv->client,
-                                            info->priv->enabled_notification_id);
-
-                info->priv->enabled_notification_id = 0;
+        if (info->priv->settings != NULL) {
+                g_object_unref (info->priv->settings);
         }
 
-        g_object_unref (info->priv->client);
-
         G_OBJECT_CLASS (gnome_settings_plugin_info_parent_class)->finalize (object);
 }
 
@@ -164,7 +157,6 @@ static void
 gnome_settings_plugin_info_init (GnomeSettingsPluginInfo *info)
 {
         info->priv = GNOME_SETTINGS_PLUGIN_INFO_GET_PRIVATE (info);
-        info->priv->client = gconf_client_get_default ();
 }
 
 static void
@@ -185,7 +177,7 @@ gnome_settings_plugin_info_fill_from_file (GnomeSettingsPluginInfo *info,
         int       priority;
         gboolean  ret;
 
-        gnome_settings_profile_start (NULL);
+        gnome_settings_profile_start ("%s", filename);
 
         ret = FALSE;
 
@@ -290,47 +282,11 @@ gnome_settings_plugin_info_fill_from_file (GnomeSettingsPluginInfo *info,
 
         ret = TRUE;
  out:
-        gnome_settings_profile_end (NULL);
+        gnome_settings_profile_end ("%s", filename);
 
         return ret;
 }
 
-static void
-plugin_enabled_cb (GConfClient             *client,
-                   guint                    cnxn_id,
-                   GConfEntry              *entry,
-                   GnomeSettingsPluginInfo *info)
-{
-        if (gconf_value_get_bool (entry->value)) {
-                gnome_settings_plugin_info_activate (info);
-        } else {
-                gnome_settings_plugin_info_deactivate (info);
-        }
-}
-
-void
-gnome_settings_plugin_info_set_enabled_key_name (GnomeSettingsPluginInfo *info,
-                                                 const char              *key_name)
-{
-        char *dirname;
-
-        dirname = g_path_get_dirname (key_name);
-        if (dirname != NULL) {
-                g_debug ("Monitoring dir %s for changes", dirname);
-                gconf_client_add_dir (info->priv->client, dirname, GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
-                g_free (dirname);
-        }
-
-        info->priv->enabled_notification_id = gconf_client_notify_add (info->priv->client,
-                                                                       key_name,
-                                                                       (GConfClientNotifyFunc)plugin_enabled_cb,
-                                                                       info,
-                                                                       NULL,
-                                                                       NULL);
-
-        info->priv->enabled = gconf_client_get_bool (info->priv->client, key_name, NULL);
-}
-
 GnomeSettingsPluginInfo *
 gnome_settings_plugin_info_new_from_file (const char *filename)
 {
@@ -348,6 +304,38 @@ gnome_settings_plugin_info_new_from_file (const char *filename)
         return info;
 }
 
+static void
+plugin_enabled_cb (GSettings               *settings,
+                   const gchar             *key,
+                   GnomeSettingsPluginInfo *info)
+{
+        if (g_strcmp0 (key, "active") == 0) {
+                if (g_settings_get_boolean (settings, "active"))
+                        gnome_settings_plugin_info_activate (info);
+                else
+                        gnome_settings_plugin_info_deactivate (info);
+        }
+}
+
+void
+gnome_settings_plugin_info_set_settings_prefix (GnomeSettingsPluginInfo *info,
+                                                const char              *settings_prefix)
+{
+        int priority;
+
+        info->priv->settings = g_settings_new (settings_prefix);
+        info->priv->enabled = g_settings_get_boolean (info->priv->settings, "active");
+
+        priority = g_settings_get_int (info->priv->settings, "priority");
+        if (priority > 0)
+                info->priv->priority = priority;
+
+        g_signal_connect (G_OBJECT (info->priv->settings),
+                          "changed",
+                          G_CALLBACK (plugin_enabled_cb),
+                          info);
+}
+
 static void
 _deactivate_plugin (GnomeSettingsPluginInfo *info)
 {
@@ -388,7 +376,7 @@ load_plugin_module (GnomeSettingsPluginInfo *info)
         g_return_val_if_fail (info->priv->plugin == NULL, FALSE);
         g_return_val_if_fail (info->priv->available, FALSE);
 
-        gnome_settings_profile_start (NULL);
+        gnome_settings_profile_start ("%s", info->priv->location);
 
         switch (info->priv->loader) {
                 case GNOME_SETTINGS_PLUGIN_LOADER_C:
@@ -484,7 +472,7 @@ load_plugin_module (GnomeSettingsPluginInfo *info)
         g_type_module_unuse (info->priv->module);
         ret = TRUE;
  out:
-        gnome_settings_profile_end (NULL);
+        gnome_settings_profile_end ("%s", info->priv->location);
         return ret;
 }
 
